@@ -214,6 +214,10 @@ class CtnType(models.Model):
     def __str__(self):
         return self.name
 
+IN_OR_OUTS = (
+        ('集团内', '集团内'),
+        ('集团外', '集团外')
+)
 
 class Supplier(models.Model):
     """
@@ -227,11 +231,14 @@ class Supplier(models.Model):
     tax_id = models.CharField(max_length=40, verbose_name="税务登记号", help_text="税务登记号")
     bank_account = models.CharField(max_length=40, verbose_name="银行账号", help_text="银行账号")
     bank_name = models.CharField(max_length=40, verbose_name="开户行", help_text="开户行")
+    bank_no = models.CharField(max_length=40, verbose_name="银行编码", help_text="银行编码", null=True, blank=True)
     invoice_title = models.CharField(max_length=500, verbose_name="发票抬头", help_text="发票抬头")
     contacts = models.CharField(max_length=40, verbose_name="联系人", help_text="联系人")
     contact_num = models.CharField(max_length=40, verbose_name="联系电话", help_text="联系电话")
     if_deleted = models.BooleanField(default=False, verbose_name="是否删除")
     service_provider = models.ForeignKey(ServiceProvider, verbose_name="服务企业", on_delete=models.CASCADE)
+    in_or_out = models.CharField(choices=IN_OR_OUTS, default="集团外", null=True, blank=True, max_length=10)
+
 
     class Meta:
         verbose_name = "供应商公司"
